@@ -80,7 +80,7 @@ func multiply(preferences multiplyPreferences) func(d *dataTreeNavigator, contex
 
 func multiplyScalars(lhs *CandidateNode, rhs *CandidateNode) (*CandidateNode, error) {
 	lhsTag := lhs.Node.Tag
-	rhsTag := rhs.Node.Tag
+	rhsTag := guessTagFromCustomType(rhs.Node)
 	lhsIsCustom := false
 	if !strings.HasPrefix(lhsTag, "!!") {
 		// custom tag - we have to have a guess
@@ -88,11 +88,6 @@ func multiplyScalars(lhs *CandidateNode, rhs *CandidateNode) (*CandidateNode, er
 		lhsIsCustom = true
 	}
 
-	if !strings.HasPrefix(rhsTag, "!!") {
-		// custom tag - we have to have a guess
-		rhsTag = guessTagFromCustomType(rhs.Node)
-	}
-
 	if lhsTag == "!!int" && rhsTag == "!!int" {
 		return multiplyIntegers(lhs, rhs)
 	} else if (lhsTag == "!!int" || lhsTag == "!!float") && (rhsTag == "!!int" || rhsTag == "!!float") {
